Documentation
¶
Index ¶
Constants ¶
const TRZ = "trezor"
Variables ¶
var TP_Id int
Functions ¶
func MessageName ¶
func MessageName(kind trezorproto.MessageType) string
Name returns the friendly message type name of a specific protocol buffer type number.
func MessageType ¶
func MessageType(msg proto.Message) trezorproto.MessageType
Type returns the protocol buffer type number of a specific message. If the message is nil, this method panics!
Types ¶
type Trezor ¶
type Trezor struct {
*trezorproto.Features
USB_ID string
Name string
Pane *TrezorPane
}
connected Trezor
type TrezorPane ¶
type TrezorPane struct {
ui.PaneDescriptor
*Trezor
On bool
Id int
ViewName string
Mode string
Pin string
Pass string
// contains filtered or unexported fields
}
func NewTrezorPane ¶
func NewTrezorPane(t *Trezor) *TrezorPane
func (*TrezorPane) EstimateLines ¶
func (p *TrezorPane) EstimateLines(w int) int
func (*TrezorPane) GetDesc ¶
func (p *TrezorPane) GetDesc() *ui.PaneDescriptor
func (*TrezorPane) IsOn ¶
func (p *TrezorPane) IsOn() bool
func (*TrezorPane) SetMode ¶
func (p *TrezorPane) SetMode(mode string)
func (*TrezorPane) SetOn ¶
func (p *TrezorPane) SetOn(on bool)
func (*TrezorPane) SetView ¶
func (p *TrezorPane) SetView(x0, y0, x1, y1 int, overlap byte)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.